@@ -51,6 +51,7 @@ from .usecases import (
 
     AgeDetectionUseCase,
     WeldDefectUseCase,
+    WeaponDetectionUseCase,
 
     AgeDetectionUseCase,
     PriceTagUseCase,
@@ -153,6 +154,7 @@ class PostProcessor:
         registry.register_use_case("agriculture", "crop_weed_detection", CropWeedDetectionUseCase)
         registry.register_use_case("security", "child_monitoring", ChildMonitoringUseCase)
         registry.register_use_case("general", "gender_detection", GenderDetectionUseCase)
+        registry.register_use_case("security", "weapon_tracking", WeaponDetectionUseCase)
         
         logger.debug("Registered use cases with registry")
     
